@@ -33,14 +33,17 @@
 #define VALID 1
 #define INVALID 2
 
-AsnOid atmfPortIndex = {13, "\53\06\01\04\01\202\141\02\01\01\01\01\00"};
-AsnOid atmfMyIpNmAddress = {11, "\53\06\01\04\01\202\141\02\01\02\00"};
-AsnOid atmfAtmLayerMaxVpiBits =  {13,        "\53\06\01\04\01\202\141\02\02\01\01\6\00"};
-AsnOid atmfAtmLayerMaxVciBits =  {13,        "\53\06\01\04\01\202\141\02\02\01\01\7\00"};
-AsnOid atmfAtmLayerUniVersion =  {13,        "\53\06\01\04\01\202\141\02\02\01\01\11\00"};
+AsnOid atmfPortIndex =          {13, "\53\06\01\04\01\202\141\02\01\01\01\01\00"};
+AsnOid atmfPortMyIdentifier =   {13, "\53\06\01\04\01\202\141\02\01\01\01\10\00"};
+AsnOid atmfMyIpNmAddress =      {11, "\53\06\01\04\01\202\141\02\01\02\00"};
+AsnOid atmfMySystemIdentifier = {11, "\53\06\01\04\01\202\141\02\01\04\00"};
+AsnOid atmfAtmLayerMaxVpiBits = {13, "\53\06\01\04\01\202\141\02\02\01\01\6\00"};
+AsnOid atmfAtmLayerMaxVciBits = {13, "\53\06\01\04\01\202\141\02\02\01\01\7\00"};
+AsnOid atmfAtmLayerUniVersion = {13, "\53\06\01\04\01\202\141\02\02\01\01\11\00"};
 AsnOid atmfNetPrefixStatus = {NETPREFIX_LEN, "\53\06\01\04\01\202\141\02\07\01\01\03"};
 
 AsnInt atmfPortIndexValue = 0;
+AsnOcts atmfMySystemIdentifierValue = {6 , NULL};
 IpAddress atmfMyIpNmAddressValue = {4 , NULL};
 
 /* The following two values depend on the capabilities of both
