@@ -451,7 +451,7 @@ load_vars(const char *file)
 {
   const Unit_t *curr_unit = NULL;
 
-  int ret;
+  int ret = 0;   /* to silence gcc 2.7.2.1 */
   char *varname;
   InitPvc_t *pvc;
   LaneDestList_t *ltmp;
