@@ -9,7 +9,7 @@
 #include <sys/socket.h>
 #include <sys/ioctl.h>
 
-#include "atm.h"
+#include <atm.h>
 #include <linux/atmdev.h>
 
 
