@@ -1,6 +1,6 @@
 /* sscop.c - SSCOP (Q.2110) protocol */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -53,8 +53,6 @@
 #define COMPONENT "SSCOP"
 
 
-/*#define debug (void)*/
-
 /* Configurable SSCOP parameters */
 
 #define SSCOP_CF_MR	 30	/* buffer size */
@@ -142,8 +140,7 @@ static void maa_error(void *arg,char code,int count)
 
 static int sdu_length(BUFFER *buf)
 {
-    return buf->length-4-SSCOP_PAD(*(uint32_t *) ((char *) buf->data+
-      buf->length-4));
+    return buf->length-4-SSCOP_PAD((char *) buf->data+buf->length-4);
 }
 
 
@@ -229,7 +226,7 @@ static void emit_pdu(SSCOP_DSC *dsc,BUFFER *buf)
     }
     if (dsc->ops->cpcs_send)
 	dsc->ops->cpcs_send(dsc->user,buf->data,buf->length);
-    switch (SSCOP_TYPE(*(uint32_t *) ((char *) buf->data+buf->length-4))) {
+    switch (SSCOP_TYPE((char *) buf->data+buf->length-4)) {
 	case SSCOP_BGN:
 	    last = &dsc->last_bgn;
 	    break;
@@ -782,11 +779,11 @@ static void data_ustat(SSCOP_DSC *dsc,int mr,int r,int e1,int e2) /* 20.43 */
 }
 
 
-static void data_stat(SSCOP_DSC *dsc,int ps,int mr,int r,uint32_t *list,
+static void data_stat(SSCOP_DSC *dsc,int ps,int mr,int r,void *list,
   int length) /* 20.44-46 */
 {
     BUFFER *buf,*buf2;
-    uint32_t *curr,tmp;
+    char *curr;
     int i,count,seq1,seq2;
 
     if (NEGATIVE(NORM_TXP(ps)) || NORM_TXP(ps) > NORM_TXP(dsc->vt_ps)) {
@@ -813,8 +810,8 @@ static void data_stat(SSCOP_DSC *dsc,int ps,int mr,int r,uint32_t *list,
     curr = list;
     count = 0;
     if (i > 1) {
-	tmp = *curr++;
-	seq1 = SSCOP_N(tmp);
+	seq1 = SSCOP_N(curr);
+	curr += 4;
 	i--;
 	if (NORM_TX(seq1) >= NORM_TX(dsc->vt_s)) {
 	    /* H */
@@ -823,8 +820,8 @@ static void data_stat(SSCOP_DSC *dsc,int ps,int mr,int r,uint32_t *list,
 	}
 	/* I */
 	do {
-	    tmp = *curr++;
-	    seq2 = SSCOP_N(tmp);
+	    seq2 = SSCOP_N(curr);
+	    curr += 4;
 	    i--;
 	    if (NORM_TX(seq1) >= NORM_TX(seq2) ||
 	      NORM_TX(seq2) > NORM_TX(dsc->vt_s)) {
@@ -850,8 +847,8 @@ static void data_stat(SSCOP_DSC *dsc,int ps,int mr,int r,uint32_t *list,
 	    while (seq1 != seq2);
 	    /* J */
 	    if (!i) break;
-	    tmp = *curr++;
-	    seq2 = SSCOP_N(tmp);
+	    seq2 = SSCOP_N(curr);
+	    curr += 4;
 	    i--;
 	    if (NORM_TX(seq1) >= NORM_TX(seq2) ||
 	      NORM_TX(seq2) > NORM_TX(dsc->vt_s)) {
@@ -1433,8 +1430,7 @@ static int handle_sscop_pdu(SSCOP_DSC *dsc,void *msg,int size)
 		    data_poll(dsc,s);
 		    return 1;
 		case SSCOP_USTAT:
-		    data_ustat(dsc,mr,r,SSCOP_N(((uint32_t *) msg)[0]),
-		      SSCOP_N(((uint32_t *) msg)[1]));
+		    data_ustat(dsc,mr,r,SSCOP_N(msg),SSCOP_N((char *) msg+4));
 		    return 1;
 		case SSCOP_STAT:
 		    data_stat(dsc,ps,mr,r,msg,length/4);
