@@ -315,7 +315,8 @@ static void usage(const char *name)
     fprintf(stderr,"usage: %s [ -b ] [ -c config_file ] [ -d ] "
       "[ -D dump_dir ]\n"
       "  [ -l logfile ] [ -n ] [ -m user|network|switch ]  [ -q qos ]\n"
-      "  [ -t trace_length ] [ [itf.]vpi.vci [ socket_path ] ]\n",name);
+      "  [ -t trace_length ] [ -u uni_version ] [ [itf.]vpi.vci "
+      "[ socket_path ] ]\n",name);
     exit(1);
 }
 
@@ -333,7 +334,7 @@ int main(int argc,char **argv)
     background = 0;
     memset(&_entity.signaling_pvc,0,sizeof(_entity.signaling_pvc));
     /* 1st pass to get the -c option */
-    while ((c = getopt(argc,argv,"Abc:dD:l:m:nNP:q:t:")) != EOF)
+    while ((c = getopt(argc,argv,"Abc:dD:l:m:nNP:q:t:u:")) != EOF)
 	if (c == 'c') config_file = optarg;
     if (!(yyin = fopen(config_file,"r")))
 	diag(COMPONENT,DIAG_WARN,"%s not found. - Using defaults.",config_file);
@@ -359,7 +360,7 @@ int main(int argc,char **argv)
 	    ;
     /* process all other options but -c */
     optind = 0;
-    while ((c = getopt(argc,argv,"Abc:dD:l:m:nNP:q:t:")) != EOF)
+    while ((c = getopt(argc,argv,"Abc:dD:l:m:nNP:q:t:u:")) != EOF)
 	switch (c) {
 	    case 'A':
 		manual_override();
@@ -415,6 +416,27 @@ int main(int argc,char **argv)
 		trace_size = strtol(optarg,&end,0);
 		if (*end) usage(argv[0]);
 		break;
+	    case 'u':
+		manual_override();
+		{
+		    int uni = 0; /* silence gcc */
+
+		    if (!strcmp(optarg,"uni30")) uni = S_UNI30;
+		    else if (!strcmp(optarg,"uni31")) uni = S_UNI31;
+		    else if (!strcmp(optarg,"uni31+uni30"))
+			uni = S_UNI30 | S_UNI31;
+		    else if (!strcmp(optarg,"uni40")) uni = S_UNI40;
+		    else if (!strcmp(optarg,"uni40+q.2963.1"))
+			uni = S_UNI40 | S_Q2963_1;
+		    else usage(argv[0]);
+#ifdef DYNAMIC_UNI
+		    _entity.uni = uni;
+#else
+	    	    diag(COMPONENT,DIAG_FATAL,"Signaling version specified "
+		      "with -s conflicts with compiled-in default.");
+#endif
+		}
+		break;
 	    default:
 		usage(argv[0]);
 	}
