@@ -1,7 +1,7 @@
 /* switch.c - Handles signaling an ATM switch */
 
 /* Written 1997-1998 by Roman Pletka, EPFL SSC */
-/* Modified 1998 by Werner Almesberger, EPFL ICA */
+/* Modified 1998-2000 by Werner Almesberger, EPFL ICA */
 
 
 #include <stdio.h>
@@ -140,7 +140,7 @@ static void from_called(CALL *call,struct atmsvc_msg *msg)
 		    /* save msg content in call */
 		    call->out.qos = msg->qos;
 		    new_state(call,cs_called_accepted);
-		    fab_op(call,RM_CLAIM(_RM_ANY),NULL,from_fab,NULL);
+		    fab_op(call,RM_CLAIM(_RM_ANY),&msg->qos,from_fab,NULL);
 		    return;
 		case as_error:
 		    send_reject(call,msg->reply);
